#include "hatpNode.hh"

using namespace std;

hatpNode::hatpNode(unsigned int id, string type, string name, vector<string> ags, unsigned int stime, unsigned int etime, vector<string > params) {
	this->nodeID = id;
	this->nodeType = type;
	this->taskName = name;
	this->agents = ags;
	this->startTime = stime;
	this->endTime = etime;
	this->parameters = params;
	this->rootnode = 0;
}

hatpNode::~hatpNode() {}

unsigned int hatpNode::getID() const {
	return this->nodeID;
}

string hatpNode::getType() const {
	return this->nodeType;
}

string hatpNode::getName() const {
	return this->taskName;
}

vector<string> hatpNode::getAgents() const {
	return this->agents;
}

unsigned int hatpNode::getStartTime() const {
	return this->startTime;
}

unsigned int hatpNode::getEndTime() const {
	return this->endTime;
}

vector<string> hatpNode::getParameters() const {
	return this->parameters;
}

unsigned int hatpNode::getRootNode() const {
	return this->rootnode;
}

vector<unsigned int> hatpNode::getSubNodes() const {
	return this->subnodes;
}

vector<unsigned int> hatpNode::getTreePredecessors() const {
	return this->treePredecessors;
}

vector<unsigned int> hatpNode::getTreeSuccessors() const {
	return this->treeSuccessors;
}

vector<unsigned int> hatpNode::getStreamPredecessors() const {
	return this->streamPredecessors;
}

vector<unsigned int> hatpNode::getStreamSuccessors() const {
	return this->streamSuccessors;
}

bool hatpNode::isAction() const {
	return (this->nodeType == TYPE_ACTION);
}

void hatpNode::setRootNode(unsigned int n) {
	this->rootnode = n;
}

void hatpNode::addSubNode(unsigned int n) {
	this->subnodes.push_back(n);
}

void hatpNode::addTreePredecessor(unsigned int n) {
	this->treePredecessors.push_back(n);
}

void hatpNode::addTreeSuccessor(unsigned int n) {
	this->treeSuccessors.push_back(n);	
}

void hatpNode::addStreamPredecessor(unsigned int n) {
	this->streamPredecessors.push_back(n);
}

void hatpNode::addStreamSuccessor(unsigned int n) {
	this->streamSuccessors.push_back(n);	
}

string hatpNode::toString() const {
	ostringstream result;
	result << "NODE ID " << this->nodeID << " (" << this->nodeType << "):\n";
	result << "\t name = " << this->taskName << "\n";
	result << "\t agents = [";
	for(unsigned int i = 0 ; i < this->agents.size() ; i++ ) result << this->agents[i] << " ";
	result << "]"<< "\n";
	result << "\t time = {" << this->startTime << ", " << this->endTime << "}\n";
	result << "\t parameters = [";
	for(unsigned int i = 0 ; i < this->parameters.size() ; i++ ) result << this->parameters[i] << " ";
	result << "]"<< "\n";
	result << "\t rootnode = " << this->rootnode << "\n";	
	result << "\t subnodes = [";
	for(unsigned int i = 0 ; i < this->subnodes.size() ; i++ ) result << this->subnodes[i] << " ";
	result << "]"<< "\n";	
	result << "\t (tree)predecessors = [";
	for(unsigned int i = 0 ; i < this->treePredecessors.size() ; i++ ) result << this->treePredecessors[i] << " ";
	result << "]"<< "\n";	
	result << "\t (tree)successors = [";
	for(unsigned int i = 0 ; i < this->treeSuccessors.size() ; i++ ) result << this->treeSuccessors[i] << " ";
	result << "]"<< "\n";
	result << "\t (stream)predecessors = [";
	for(unsigned int i = 0 ; i < this->streamPredecessors.size() ; i++ ) result << this->streamPredecessors[i] << " ";
	result << "]"<< "\n";	
	result << "\t (stream)successors = [";
	for(unsigned int i = 0 ; i < this->streamSuccessors.size() ; i++ ) result << this->streamSuccessors[i] << " ";
	result << "]"<< "\n";
	return result.str();
}

